@@ -1,4 +1,4 @@
-#  Copyright (c) 2021 Mira Geoscience Ltd.
+#  Copyright (c) 2022 Mira Geoscience Ltd.
 #
 #  This file is part of geoapps.
 #
@@ -7,9 +7,7 @@
 
 from uuid import UUID
 
-import numpy as np
 from geoh5py.groups import ContainerGroup
-from geoh5py.workspace import Workspace
 
 from geoapps.io.Inversion.constants import default_ui_json as base_default_ui_json
 from geoapps.io.Inversion.constants import (
@@ -127,7 +125,6 @@ inversion_defaults = {
     "parallelized": True,
     "n_cpu": None,
     "max_ram": None,
-    "workspace": None,
     "out_group": "VectorInversion",
     "no_data_value": None,
     "monitoring_directory": None,
@@ -203,7 +200,6 @@ forward_defaults = {
     "window_azimuth": None,
     "parallelized": True,
     "n_cpu": None,
-    "workspace": None,
     "out_group": "MVIForward",
     "monitoring_directory": None,
     "workspace_geoh5": None,
